@@ -11,9 +11,8 @@ standard_library.install_aliases()
 
 import collections
 from shutil import copyfile  # NOQA: #402
-from construct import *  # NOQA: #402
-from valvebsp.constants import LUMP_GAME_LUMP  # NOQA: #402
 
+from construct import *  # NOQA: #402
 import valvebsp.structs.bsp as BSP  # NOQA: #402
 
 try:
@@ -22,6 +21,10 @@ except AttributeError:
     collectionsAbc = collections
 
 
+class LumpUnsupportedError(IndexError):
+    pass
+
+
 def byte_align(filelen, align=4):
     if (filelen % align):
         filelen += (align - filelen % align)
@@ -69,16 +72,29 @@ class Bsp(collectionsAbc.MutableMapping):
 
         dest = destination or self.source_path
         header_struct = BSP.header(self.profile)
-        try:
-            d = open(dest, 'wb+')
-        except:
+
+        if not dest:
+            # save location is invalid
             raise FileNotFoundError
 
-        if not self.source_path:
-            self._build_stream(header_struct, self.header, d)
+        elif not self.source_path:
+            # creating a new file from nothing
+            try:
+                d = open(dest, 'wb')
+                self._build_stream(header_struct, self.header, d)
+            except:
+                raise FileNotFoundError
 
-        elif dest != self.source_path:
+        elif dest == self.source_path:
+            # overwritting original file
+            try:
+                d = open(dest, 'rb+')
+            except:
+                raise FileNotFoundError
+        else:
+            # source and dest are different
             s = open(self.source_path, 'rb')
+            d = open(dest, 'wb+')
             d.write(s.read())
             s.close()
 
@@ -174,7 +190,7 @@ class Bsp(collectionsAbc.MutableMapping):
             if index in range(64) and self.header:
                 return self.header.lump_t[index]
 
-        raise IndexError('Invalid Lump ID (' + str(index) + ')')
+        raise LumpUnsupportedError('Invalid Lump ID (' + str(index) + ')')
 
     def _get_lump_struct(self, index):
         lump_header = self._get_lump_header(index)
@@ -190,10 +206,6 @@ class Bsp(collectionsAbc.MutableMapping):
         :type index: str, int
         """
 
-        if index not in range(0, 64) and \
-           index not in ['prps', 'prpd', 'tlpd', 'hlpd']:
-            raise LumpUnsupportedError(index)
-
         if index in self.lumps and self.lumps[index]:
             return self.lumps[index]
 
