@@ -12,11 +12,17 @@ from __future__ import unicode_literals
 from future import standard_library
 standard_library.install_aliases()
 
-from collections.abc import Iterable
 from construct import *  # NOQA: E402
 from valvebsp.constants import *  # NOQA: E402
 from valvebsp.exceptions import *  # NOQA: #402
 
+import collections
+try:
+    Iterable = collections.abc.Iterable
+except AttributeError:
+    Iterable = collections.Iterable
+
+
 Vector = Struct('x' / Float32l, 'y' / Float32l, 'z' / Float32l)
 
 
@@ -29,8 +35,8 @@ Quaternion = Struct('x' / Float32l, 'y' / Float32l,
                     'z' / Float32l, 'w' / Float32l)
 color32 = Struct('r' / Int8ul, 'g' / Int8ul, 'b' / Int8ul, 'a' / Int8ul)
 ColorRGBExp32 = Struct('r' / Byte, 'g' / Byte, 'b' /
-                       Byte, 'exponent' / Byte)
-CompressedLightCube = Struct('color' / ColorRGBExp32[6])
+                       Byte, 'exponent' / Int8sl)
+CompressedLightCube = Array(6, ColorRGBExp32)
 
 
 def lump_version(versions):
@@ -68,3 +74,12 @@ def lump_array(func):
     def wrapper(*args, **kwargs):
         return GreedyRange(func(*args, **kwargs).compile())
     return wrapper
+
+
+def lump_prefixed_array(prefix):
+    # helper for prefixed array based lumps
+    def decorator(func):
+        def wrapper(*args, **kwargs):
+            return PrefixedArray(prefix, func(*args, **kwargs))
+        return wrapper
+    return decorator
