@@ -13,8 +13,6 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
 
 dedge_t = Struct(
@@ -22,7 +20,7 @@ dedge_t = Struct(
 )
 
 
+@lump_array
+@lump_version(0)
 def lump_12(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_array(LUMP_EDGES, dedge_t, header)
+    return dedge_t
