@@ -14,6 +14,7 @@ standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
+from valvebsp.structs.flags import dworldlight_flags32  # NOQA: #402
 
 emittype_t = Enum(
     Int32ul,
@@ -24,11 +25,6 @@ emittype_t = Enum(
     emit_quakelight=4,
     emit_skyambient=5)
 
-dworldlight_flags32 = FlagsEnum(
-    Int32sl,
-    DWL_FLAGS_INAMBIENTCUBE=0,
-    DWL_FLAGS_CASTENTITYSHADOWS=1)
-
 dworldlight_tV0 = Struct(
     'origin' / Vector,
     'intensity' / Vector,
@@ -44,7 +40,7 @@ dworldlight_tV0 = Struct(
     'linearAttn' / Float32l,
     'quadraticAttn' / Float32l,
     'flags' / dworldlight_flags32,
-    'texinfo' / Int32sl * "index into :ref:`lump 2<lump_2>`",
+    'texinfo' / Int32sl * "index into :ref:`lump 6<lump_6>`",
     'owner' / Int32sl * "index into :ref:`lump 0<lump_0>`"
 )
 
@@ -64,7 +60,7 @@ dworldlight_tV1 = Struct(
     'linearAttn' / Float32l,
     'quadraticAttn' / Float32l,
     'flags' / dworldlight_flags32,
-    'texinfo' / Int32sl * "index into :ref:`lump 2<lump_2>`",
+    'texinfo' / Int32sl * "index into :ref:`lump 6<lump_6>`",
     'owner' / Int32sl * "index into :ref:`lump 0<lump_0>`"
 )
 
