@@ -14,11 +14,12 @@ standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
+from valvebsp.structs.flags import contents_flags32  # NOQA: #402
 
 dbrush_t = Struct(
     'firstSide' / Int32sl * "index into :ref:`lump 19<lump_19>`",
     'numSides' / Int32sl,
-    'contents' / Int32sl,
+    'contents' / contents_flags32,
 )
 
 
