@@ -14,8 +14,6 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
 
 dtexdata_t = Struct(
@@ -28,7 +26,7 @@ dtexdata_t = Struct(
 )
 
 
+@lump_array
+@lump_version(0)
 def lump_2(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_array(LUMP_TEXDATA, dtexdata_t, header)
+    return dtexdata_t
