@@ -13,8 +13,6 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
 
 dareaportal_t = Struct(
@@ -26,7 +24,7 @@ dareaportal_t = Struct(
 )
 
 
+@lump_array
+@lump_version(0)
 def lump_21(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_array(LUMP_AREAPORTALS, dareaportal_t, header)
+    return dareaportal_t
