@@ -13,8 +13,6 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA #402
 
 dprimitive_type = Enum(
@@ -25,14 +23,14 @@ dprimitive_type = Enum(
 
 dprimitive_t = Aligned(2, Struct(
     'type' / dprimitive_type,
-    'firstIndex' / Int16ul * 'refers to lump_39',
+    'firstIndex' / Int16ul * "index into :ref:`lump 39<lump_39>`",
     'indexCount' / Int16ul,
-    'firstVert' / Int16ul * 'refers to lump_38',
+    'firstVert' / Int16ul * "index into :ref:`lump 38<lump_38>`",
     'vertCount' / Int16ul,
 ))
 
 
+@lump_array
+@lump_version(0)
 def lump_37(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_array(LUMP_PRIMITIVES, dprimitive_t, header)
+    return dprimitive_t
