@@ -13,8 +13,6 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA #402
 
 dcubemapsample_t = Struct(
@@ -23,7 +21,7 @@ dcubemapsample_t = Struct(
 )
 
 
+@lump_array
+@lump_version(0)
 def lump_42(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_array(LUMP_CUBEMAPS, dcubemapsample_t, header)
+    return dcubemapsample_t
