@@ -12,16 +12,14 @@ from __future__ import unicode_literals
 from future import standard_library
 standard_library.install_aliases()
 
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA #402
 from valvebsp.structs.lump_15 import dworldlight_tV0, dworldlight_tV1  # NOQA #402
 
 
+@lump_array
+@lump_version([0, 1])
 def lump_54(header, profile=None):
     if header.version == 0:
-        return lump_array(LUMP_WORLDLIGHTS_HDR, dworldlight_tV0, header)
+        return dworldlight_tV0
     elif header.version == 1:
-        return lump_array(LUMP_WORLDLIGHTS_HDR, dworldlight_tV1, header)
-    else:
-        raise LumpVersionUnsupportedError(header.version)
+        return dworldlight_tV1
