@@ -2,7 +2,7 @@
 Lump 59 - Map Flags
 ===================
 
-This lump contains an array of :any:`flags_t`.
+This lump contains a single :any:`flags_t`.
 """
 
 from __future__ import division
@@ -14,13 +14,9 @@ standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA #402
+from valvebsp.structs.flags import levelflags_flags32  # NOQA: #402
 
-flags_flags = FlagsEnum(
-    Int32ul,
-    BAKED_STATIC_PROP_LIGHTING_NONHDR=1,
-    BAKED_STATIC_PROP_LIGHTING_HDR=2)
-
-flags_t = Struct('levelFlags' / flags_flags)
+flags_t = Struct('levelFlags' / levelflags_flags32)
 
 
 @lump_struct
