@@ -21,8 +21,8 @@ dface_t = Struct(
     'onNode' / Byte,
     'firstedge' / Int32sl * "index into :ref:`lump 13<lump_13>`",
     'numedges' / Int16sl,
-    'texinfo' / Int16sl,
-    'dispinfo' / Int16sl,
+    'texinfo' / Int16sl * "index into :ref:`lump 6<lump_6>`",
+    'dispinfo' / Int16sl * "index into :ref:`lump 26<lump_26>`",
     'surfaceFogVolumeID' / Int16sl,
     'styles' / Byte[4],
     'lightofs' / Int32sl * "index into :ref:`lump 8<lump_8>`",
