@@ -2,7 +2,7 @@
 Lump hlpd - Prop Detail Lighting HDR
 ====================================
 
-This lump is the HDR version of :ref:`lump tlpd<lump_tlpd>`, its structure is identical
+This lump is the HDR version of :ref:`lump tlpd<lump_tlpd>`, its structure is identical.
 """
 
 from __future__ import division
@@ -13,10 +13,10 @@ from future import standard_library
 standard_library.install_aliases()
 
 from valvebsp.structs.common import *  # NOQA #402
-from valvebsp.structs.lump_tlpd import DetailPropLightStylesLump_t  # NOQA #402
+from valvebsp.structs.lump_tlpd import DetailPropLightStyle_t  # NOQA #402
 
 
-@lump_struct
+@lump_prefixed_array(Int32sl)
 @lump_version(0)
 def lump_hlpd(header, profile=None):
-    return DetailPropLightStylesLump_t
+    return DetailPropLightStyle_t
