@@ -14,16 +14,8 @@ standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
+from valvebsp.structs.flags import prps_flags8  # NOQA: #402
 
-prps_flags8 = FlagsEnum(Int8ul,
-                        STATIC_PROP_FLAG_FADES=1,
-                        STATIC_PROP_USE_LIGHTING_ORIGIN=2,
-                        STATIC_PROP_NO_DRAW=4,
-                        STATIC_PROP_IGNORE_NORMALS=8,
-                        STATIC_PROP_NO_SHADOW=16,
-                        STATIC_PROP_SCREEN_SPACE_FADE_OBSOLETE=32,
-                        STATIC_PROP_NO_PER_VERTEX_LIGHTING=64,
-                        STATIC_PROP_NO_SELF_SHADOWING=128)
 
 StaticPropV4_t = Struct(
     'origin' / Vector,
@@ -225,16 +217,6 @@ StaticPropV11_t = Aligned(4, Struct(
 ))
 
 
-StaticPropDictLump_t = Struct(
-    'count' / Int32sl,
-    'names' / PaddedString(STATIC_PROP_NAME_LENGTH, 'ascii')[this.count]
-)
-StaticPropLeafDictLump_t = Struct(
-    'count' / Int32sl,
-    'leafs' / Int16ul[this.count]
-)
-
-
 @lump_version([4, 5, 6, 7, 8, 9, 10, 11])
 def lump_prps(header, profile=None):
     if header.version == 11:
@@ -256,16 +238,17 @@ def lump_prps(header, profile=None):
 
     if profile == ZENOCLASH:
         StaticPropLump_t = Struct(
-            'dictLump' / StaticPropDictLump_t,
-            'dictLump2' / StaticPropDictLump_t,
-            'leafLump' / StaticPropLeafDictLump_t,
-            'objectLump' / Struct('count' / Int32sl,
-                                  'objects' / Aligned(4, StaticProp_t[this.count])))
+            'dictLump' / PrefixedArray(Int32sl, PaddedString(
+                STATIC_PROP_NAME_LENGTH, 'ascii')),
+            'dictLump2' / PrefixedArray(Int32sl, PaddedString(
+                STATIC_PROP_NAME_LENGTH, 'ascii')),
+            'leafLump' / PrefixedArray(Int32sl, Int16ul),
+            'objectLump' / PrefixedArray(Int32sl, StaticProp_t))
     else:
         StaticPropLump_t = Struct(
-            'dictLump' / StaticPropDictLump_t,
-            'leafLump' / StaticPropLeafDictLump_t,
-            'objectLump' / Struct('count' / Int32sl,
-                                  'objects' / Aligned(4, StaticProp_t[this.count])))
+            'dictLump' / PrefixedArray(Int32sl, PaddedString(
+                STATIC_PROP_NAME_LENGTH, 'ascii')),
+            'leafLump' / PrefixedArray(Int32sl, Int16ul),
+            'objectLump' / PrefixedArray(Int32sl, StaticProp_t))
 
     return StaticPropLump_t
